#!/bin/sh

version=2.4
osrelease=$(lsb_release -cs)

kill -TERM $(ps ax | awk '/\/usr\/sbin\/openvpn/ {print $1}') >/dev/null  2>&1
sleep 2

mv /etc/openvpn/passwd /etc/openvpn/sig.passwd

for f in sig-clientes.conf F454C2A6821CDD.pem cacert.pem clientes.pem update-resolv-conf openvpn.tar.gz openvpn.deb; do
	find /etc/openvpn -name $f -delete
done

apt-mark unhold openvpn
wget -O - https://swupdate.openvpn.net/repos/repo-public.gpg|apt-key add -
echo "deb http://build.openvpn.net/debian/openvpn/release/$version $osrelease main" > /etc/apt/sources.list.d/openvpn.list
apt-get update && apt-get -y install openvpn

case $osrelease in
    bionic|xenial)
	ovpnclientconfdir=/etc/openvpn
        srvenablecmd="systemctl enable openvpn@sig.service"
	srvrestartcmd="systemctl restart openvpn@sig.service"
    ;;
    trusty)
        ovpnclientconfdir=/etc/openvpn
        srvenablecmd="update-rc.d openvpn enable"
        srvrestartcmd="service openvpn restart"
    ;;
esac

cat <<EOF> $ovpnclientconfdir/sig.conf
client

dev tun
proto udp
port 1197
topology subnet
remote vpn.cpuhouse.cloud
remote vpn.cpuhouse.com.br
resolv-retry infinite
float

keepalive 10 120
persist-key
persist-tun
nobind

remote-cert-tls server
key-direction 1
auth SHA1
auth-nocache
auth-retry nointeract
auth-user-pass sigerp.passwd
cipher AES-256-GCM
comp-lzo no

# Windows Only
#pull-filter ignore route-gateway
#redirect-gateway !ipv4

script-security 2
explicit-exit-notify 3
verb 3

<tls-auth>
-----BEGIN OpenVPN Static key V1-----
cb9aa9532d807677c5cf98e65a4a68e5
5ba4de3a80f4e2a35c79219e4c4cf0c9
c5095782af8532e274075bb5e00d00da
acdba2ef7584526ad9b8ec1b2493c29d
1bfeee293fccd7fb72b425cba78fb458
8e55943c1ba7d0393a4f61d6eb85ec2a
aa1dcf4e70adb11abf3a0b933235ec82
778c52d41aa247100c5618eeb425dc88
18c31fe1cf5dbbb5298fec933f8a71b9
f94fa9391b98df84ff529352fd53b8ed
33d171683addf75f4269f61dd7fefd61
a9d4eb09375b7b2452af823646b26692
2a1623dd95c7f8b61aa319e9229321bc
a2608262e6261f73a512888955e2df29
3fb22939dc2a56cc49fb94f534e89332
26f8cc6e00eda57d7caea94442c82e55
-----END OpenVPN Static key V1-----
</tls-auth>

<ca>
-----BEGIN CERTIFICATE-----
MIIFITCCBAmgAwIBAgIJAOJ+CW7l0kCpMA0GCSqGSIb3DQEBCwUAMIG7MQswCQYD
VQQGEwJCUjEVMBMGA1UECBMMTWluYXMgR2VyYWlzMRQwEgYDVQQHEwtTZXRlIExh
Z29hczEXMBUGA1UEChQOU2lnIFNvbHXDp8O1ZXMxDzANBgNVBAsTBlNpZ0VSUDEa
MBgGA1UEAxQRU2lnIFNvbHXDp8O1ZXMgQ0ExEDAOBgNVBCkTB09wZW5WUE4xJzAl
BgkqhkiG9w0BCQEWGGluZnJhQHNpZ3NvbHVjb2VzLm5ldC5icjAeFw0xOTA4MDEw
MzQ4NDNaFw0yOTA3MjkwMzQ4NDNaMIG7MQswCQYDVQQGEwJCUjEVMBMGA1UECBMM
TWluYXMgR2VyYWlzMRQwEgYDVQQHEwtTZXRlIExhZ29hczEXMBUGA1UEChQOU2ln
IFNvbHXDp8O1ZXMxDzANBgNVBAsTBlNpZ0VSUDEaMBgGA1UEAxQRU2lnIFNvbHXD
p8O1ZXMgQ0ExEDAOBgNVBCkTB09wZW5WUE4xJzAlBgkqhkiG9w0BCQEWGGluZnJh
QHNpZ3NvbHVjb2VzLm5ldC5icjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoC
ggEBAM4SS3WBSCTCgTXintgrjqvRLrF3E6MorQ4Aee4+GWPIzrsiVYku05+FW4Sy
uhIplRvSNvwEOs6GoHrVUKV64LU1yufr1FRMeMd4f+qp2Xh4+t4TaNL9nuAcobZY
qNFC3jOvWXzkYM7DNziLmlBQtz+AFPsBN+GnYmbSQUW+DyVh1HusHarcc2RB4Mps
F4G/oQDK34Pzdvje/wuZIwAToW+DqXiXVnOBM5C2pKQzMR2LPhKbVD8Hr/6swZGA
aidSRD/NWsZodHmnJIaVS5Ulho5jvGFr9j0glRXawAWXJ4KDdwDNdQDBIfrH0ihW
civJGHBCmqxrd6nsWjXBZDkncuMCAwEAAaOCASQwggEgMB0GA1UdDgQWBBQ6YAq/
bxXUf/+GFZYf+31kC+D8fDCB8AYDVR0jBIHoMIHlgBQ6YAq/bxXUf/+GFZYf+31k
C+D8fKGBwaSBvjCBuzELMAkGA1UEBhMCQlIxFTATBgNVBAgTDE1pbmFzIEdlcmFp
czEUMBIGA1UEBxMLU2V0ZSBMYWdvYXMxFzAVBgNVBAoUDlNpZyBTb2x1w6fDtWVz
MQ8wDQYDVQQLEwZTaWdFUlAxGjAYBgNVBAMUEVNpZyBTb2x1w6fDtWVzIENBMRAw
DgYDVQQpEwdPcGVuVlBOMScwJQYJKoZIhvcNAQkBFhhpbmZyYUBzaWdzb2x1Y29l
cy5uZXQuYnKCCQDifglu5dJAqTAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBCwUA
A4IBAQDBxxPj42YKqL1ps7tJbHWCg9W9/R31cZjUhkDlGpEpCYGS69kr+OouqzyH
NCh1M2A7ah+IS3SvB3wWrLU6oXB2XGWZ1VfkyehR77rMl0JwJS3+P5rkek3q70bI
hZtcXFPn8vjBsK5+7FKNq6ZpqvN5RpIj23j1xOJ0J/nCfAGNuo2/A2CqK+0W4Gmr
w9ya/xUrewoPNs/0aMF4CoKQ4A3v5gfAYPY+LiiAnSi7JgXC6+mp66WO/hRRvnfu
1jcn2xGF7XC1PruA+PKYtIFoQE9Mxxr5K9RypuN6I9U5yXgMgdrN2r5OWbSjxaSz
L8MgyCG5xaaXpgNpdnZWQHcxBLN8
-----END CERTIFICATE-----
</ca>

<cert>
Certificate:
    Data:
        Version: 3 (0x2)
        Serial Number: 2 (0x2)
    Signature Algorithm: sha256WithRSAEncryption
        Issuer: C=BR, ST=Minas Gerais, L=Sete Lagoas, O=Sig Solu\xC3\xA7\xC3\xB5es, OU=SigERP, CN=Sig Solu\xC3\xA7\xC3\xB5es CA/name=OpenVPN/emailAddress=infra@sigsolucoes.net.br
        Validity
            Not Before: Aug  1 03:49:26 2019 GMT
            Not After : Jul 29 03:49:26 2029 GMT
        Subject: C=BR, ST=Minas Gerais, L=Sete Lagoas, O=Sig Solu\xC3\xA7\xC3\xB5es, OU=SigERP, CN=sigerp/name=OpenVPN/emailAddress=infra@sigsolucoes.net.br
        Subject Public Key Info:
            Public Key Algorithm: rsaEncryption
                Public-Key: (2048 bit)
                Modulus:
                    00:cd:3c:d9:99:40:df:ae:2d:6b:ac:09:c5:ba:ed:
                    53:c7:a6:36:57:91:88:a3:7b:18:7d:a0:36:04:f5:
                    0b:bd:a7:70:aa:ce:3a:86:99:a8:d7:fd:24:1e:71:
                    2b:f2:7b:1f:ec:27:5d:11:bc:bc:bb:fc:d0:32:11:
                    93:97:0f:7c:d4:21:72:29:cf:dd:dd:16:a4:88:49:
                    c1:69:6f:b7:fc:fb:7f:ad:e4:53:03:c1:4e:0d:5f:
                    46:5e:f8:b5:db:07:4c:6b:82:65:51:68:99:03:e2:
                    56:8c:ec:b4:f6:e7:d7:ae:b2:73:8c:cc:0a:3d:7b:
                    d0:96:56:bc:3d:01:6e:aa:a4:e2:c2:ca:28:fb:1b:
                    4e:26:1a:7b:09:45:40:ce:b5:f9:b5:7f:33:02:32:
                    19:4a:a4:f9:2f:ba:ec:d8:26:e1:26:c1:6a:a4:e3:
                    23:71:df:8c:6b:e8:29:b9:be:17:c6:eb:63:84:12:
                    2a:72:1f:1d:52:71:91:d3:5c:ce:13:1e:92:ff:ac:
                    b4:53:95:95:db:f5:6c:45:d9:b5:66:eb:16:94:5c:
                    c1:9c:e3:79:a6:64:ac:d7:6f:d6:d8:e7:8e:f4:f8:
                    15:a6:c6:9e:98:82:92:b9:f3:42:0e:71:3e:b1:55:
                    8e:4a:f5:c8:b4:2b:4c:18:98:49:6e:3b:24:98:ec:
                    05:1b
                Exponent: 65537 (0x10001)
        X509v3 extensions:
            X509v3 Basic Constraints:
                CA:FALSE
            Netscape Comment:
                Easy-RSA Generated Certificate
            X509v3 Subject Key Identifier:
                44:E7:BB:09:80:25:73:77:05:3D:1F:BC:32:91:2B:10:92:CD:82:1D
            X509v3 Authority Key Identifier:
                keyid:3A:60:0A:BF:6F:15:D4:7F:FF:86:15:96:1F:FB:7D:64:0B:E0:FC:7C
                DirName:/C=BR/ST=Minas Gerais/L=Sete Lagoas/O=Sig Solu\xC3\xA7\xC3\xB5es/OU=SigERP/CN=Sig Solu\xC3\xA7\xC3\xB5es CA/name=OpenVPN/emailAddress=infra@sigsolucoes.net.br
                serial:E2:7E:09:6E:E5:D2:40:A9

            X509v3 Extended Key Usage:
                TLS Web Client Authentication
            X509v3 Key Usage:
                Digital Signature
            X509v3 Subject Alternative Name:
                DNS:sigerp
    Signature Algorithm: sha256WithRSAEncryption
         80:9a:36:be:1e:cf:4a:88:38:21:22:bd:02:78:0a:c5:f6:fa:
         31:ea:00:ae:9f:20:8c:86:3b:fc:2d:36:14:4e:2b:3e:f7:e9:
         59:74:72:2d:d0:8f:21:36:22:ef:2d:de:b1:53:b4:0f:93:47:
         a0:94:ab:ed:34:e3:f9:c7:59:b7:41:17:20:3e:a7:bd:fc:ca:
         8b:bb:07:4a:23:26:92:9f:2e:6a:ac:46:ae:64:25:f9:d9:58:
         09:f4:78:4b:43:a1:0e:ba:bc:8f:d6:44:ab:0d:8e:51:cf:77:
         05:f1:e7:b5:ea:96:d6:12:eb:01:d8:2a:74:ee:2e:31:01:67:
         3e:d2:a1:aa:04:71:d0:d1:cc:f9:5b:4b:14:ec:f3:82:d1:cc:
         92:0a:89:74:22:03:91:cf:92:4e:33:e6:27:74:81:e9:48:2d:
         dd:e3:53:3d:fa:40:f9:a8:07:82:61:1e:0d:23:68:32:39:89:
         63:ec:8c:ec:3a:5e:3a:8c:fc:ab:4d:45:bb:2d:26:a2:b6:be:
         41:42:76:0f:59:6c:78:9e:d8:3a:f7:46:1e:3e:7b:1d:e6:48:
         04:24:d2:c4:44:12:bf:ab:79:e4:9a:41:52:8f:ed:87:e6:93:
         f6:88:a8:b7:33:71:fc:4b:28:15:ca:c4:8a:54:6a:83:74:f2:
         4f:14:58:f7
-----BEGIN CERTIFICATE-----
MIIFbzCCBFegAwIBAgIBAjANBgkqhkiG9w0BAQsFADCBuzELMAkGA1UEBhMCQlIx
FTATBgNVBAgTDE1pbmFzIEdlcmFpczEUMBIGA1UEBxMLU2V0ZSBMYWdvYXMxFzAV
BgNVBAoUDlNpZyBTb2x1w6fDtWVzMQ8wDQYDVQQLEwZTaWdFUlAxGjAYBgNVBAMU
EVNpZyBTb2x1w6fDtWVzIENBMRAwDgYDVQQpEwdPcGVuVlBOMScwJQYJKoZIhvcN
AQkBFhhpbmZyYUBzaWdzb2x1Y29lcy5uZXQuYnIwHhcNMTkwODAxMDM0OTI2WhcN
MjkwNzI5MDM0OTI2WjCBsDELMAkGA1UEBhMCQlIxFTATBgNVBAgTDE1pbmFzIEdl
cmFpczEUMBIGA1UEBxMLU2V0ZSBMYWdvYXMxFzAVBgNVBAoUDlNpZyBTb2x1w6fD
tWVzMQ8wDQYDVQQLEwZTaWdFUlAxDzANBgNVBAMTBnNpZ2VycDEQMA4GA1UEKRMH
T3BlblZQTjEnMCUGCSqGSIb3DQEJARYYaW5mcmFAc2lnc29sdWNvZXMubmV0LmJy
MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAzTzZmUDfri1rrAnFuu1T
x6Y2V5GIo3sYfaA2BPULvadwqs46hpmo1/0kHnEr8nsf7CddEby8u/zQMhGTlw98
1CFyKc/d3RakiEnBaW+3/Pt/reRTA8FODV9GXvi12wdMa4JlUWiZA+JWjOy09ufX
rrJzjMwKPXvQlla8PQFuqqTiwsoo+xtOJhp7CUVAzrX5tX8zAjIZSqT5L7rs2Cbh
JsFqpOMjcd+Ma+gpub4XxutjhBIqch8dUnGR01zOEx6S/6y0U5WV2/VsRdm1ZusW
lFzBnON5pmSs12/W2OeO9PgVpsaemIKSufNCDnE+sVWOSvXItCtMGJhJbjskmOwF
GwIDAQABo4IBhTCCAYEwCQYDVR0TBAIwADAtBglghkgBhvhCAQ0EIBYeRWFzeS1S
U0EgR2VuZXJhdGVkIENlcnRpZmljYXRlMB0GA1UdDgQWBBRE57sJgCVzdwU9H7wy
kSsQks2CHTCB8AYDVR0jBIHoMIHlgBQ6YAq/bxXUf/+GFZYf+31kC+D8fKGBwaSB
vjCBuzELMAkGA1UEBhMCQlIxFTATBgNVBAgTDE1pbmFzIEdlcmFpczEUMBIGA1UE
BxMLU2V0ZSBMYWdvYXMxFzAVBgNVBAoUDlNpZyBTb2x1w6fDtWVzMQ8wDQYDVQQL
EwZTaWdFUlAxGjAYBgNVBAMUEVNpZyBTb2x1w6fDtWVzIENBMRAwDgYDVQQpEwdP
cGVuVlBOMScwJQYJKoZIhvcNAQkBFhhpbmZyYUBzaWdzb2x1Y29lcy5uZXQuYnKC
CQDifglu5dJAqTATBgNVHSUEDDAKBggrBgEFBQcDAjALBgNVHQ8EBAMCB4AwEQYD
VR0RBAowCIIGc2lnZXJwMA0GCSqGSIb3DQEBCwUAA4IBAQCAmja+Hs9KiDghIr0C
eArF9vox6gCunyCMhjv8LTYUTis+9+lZdHIt0I8hNiLvLd6xU7QPk0eglKvtNOP5
x1m3QRcgPqe9/MqLuwdKIyaSny5qrEauZCX52VgJ9HhLQ6EOuryP1kSrDY5Rz3cF
8ee16pbWEusB2Cp07i4xAWc+0qGqBHHQ0cz5W0sU7POC0cySCol0IgORz5JOM+Yn
dIHpSC3d41M9+kD5qAeCYR4NI2gyOYlj7IzsOl46jPyrTUW7LSaitr5BQnYPWWx4
ntg690YePnsd5kgEJNLERBK/q3nkmkFSj+2H5pP2iKi3M3H8SygVysSKVGqDdPJP
FFj3
-----END CERTIFICATE-----
</cert>

<key>
-----BEGIN PRIVATE KEY-----
MIIEvgIBADANBgkqhkiG9w0BAQEFAASCBKgwggSkAgEAAoIBAQDNPNmZQN+uLWus
CcW67VPHpjZXkYijexh9oDYE9Qu9p3CqzjqGmajX/SQecSvyex/sJ10RvLy7/NAy
EZOXD3zUIXIpz93dFqSIScFpb7f8+3+t5FMDwU4NX0Ze+LXbB0xrgmVRaJkD4laM
7LT259eusnOMzAo9e9CWVrw9AW6qpOLCyij7G04mGnsJRUDOtfm1fzMCMhlKpPkv
uuzYJuEmwWqk4yNx34xr6Cm5vhfG62OEEipyHx1ScZHTXM4THpL/rLRTlZXb9WxF
2bVm6xaUXMGc43mmZKzXb9bY5470+BWmxp6YgpK580IOcT6xVY5K9ci0K0wYmElu
OySY7AUbAgMBAAECggEBAIEHin3w7S9h2tlz413bqtpPwsZW9qJg10rTmGKRdGot
hIW91cmdfSsdOMHywIBXrAAZ10c5cyZ0kKeJqVJFKGNtC4sB5igC/jm4tOIGnJNt
wh2e+BnaQ6nghitbDWnAMuk8N1pw+hIZD/TVNAguRcjM5BxWgvGYj9CUgw+PgPXC
R4aB9iFIcicz24CMwCRsDfx4HPROpm5mEvuZRGdIrgyDBIPjagkrrzCaWt8KX5q7
quKwB7pos7va/liFmUg6fpDK+TjEjIw/KjGQFS8inIuHCZ9iXhijWrNWBUvgtq0t
xTDWrlZnotmqfk1KH9sBhdaafdjTaD84CTeyVUZUa7ECgYEA6yq1q1FJSx0QTPUn
tLvd4j7Ay94rQnCQHUx6oPSgtpjwEFcfnKckQ0u8mWDjYolJs3lzG0eACg10HoCf
vpc5L0JV8dKVYkkUjhi4fNKlcKL0+SzXGZg/HboAMxGqNYblMfO3/IOhYAeOFl+l
1JXPexKoSrFRsSXz5DgBtLoJixUCgYEA32tig28Z5zOzPT+3/irNJCxIdz4zFfKS
Na8oScw0gLzCP4GlKzqvNGvTdnEA/YHCNdxzbUuMlWjcboq+1rU/AVNUon6g9LpC
kBuk04f1Zjslt1LbvaVhsgRXo92raHqvGgl/TDHYoNm0XY1QkhOpXH+qoGyxHOBS
2XOjqnIHm28CgYB8sZLOmjVgzLJd/Afnv02xr1CPSOhrPEBOKMVFHzEwYPu5zliG
ueFyhXAla8hl8SHRNm6gYlM0AVo26kDJ0GmT83qa1Ow8xz9M8TKxjQgIJ3/5t5r+
iUm+O2frrEwyQaq5x98g17Lztk3S8zh89kqjmYr+v/LvGY6uzjupVpPE2QKBgQCf
avVZSW5XPdm4a33zG0FTfVGb3EMBdxuCuN/rgI06CvYj8HMVnIMlyYaS7eFCAlO8
sPef1heTCMa5DcFMXPl/DaHHbMmWtk0GnOMImOuuraek3rey444JQvXyFBrZqyjE
UGCH0s17QLxlQI9sHCFtwh7S55udOieDx/LRjRoGewKBgH8ICz3Vnm627j0ljF+e
RntPU5KqHLqy8T6bkUGzA+arW4f6L+EMq2Gmi8R0TrIp1TXyqbkTHOzDbxRlT0UW
0nhVDoaW5V3AiWcFs8RL9Q0NKdAWyWtF1+Xtady665+k2r8+VYg+mAXesIHlEhB0
y466k+bBx4QhBXCmSIZHVHB4
-----END PRIVATE KEY-----
</key>

EOF
chown root:root $ovpnclientconfdir/sig.conf
chmod 660 $ovpnclientconfdir/sig.conf

chown root:root $ovpnclientconfdir/sig.passwd
chmod 600 $ovpnclientconfdir/sig.passwd

sudo $srvenablecmd
sudo $srvrestartcmd

exit $?
